@@ -121,7 +121,7 @@ class _AttributedDict(object):
         self._enable_surrogate = True
 
     def __getstate__(self):
-        return self.__dict__.items()
+        return list(self.__dict__.items())
 
     def __setstate__(self, items):
         for key, val in items:
